@@ -127,7 +127,7 @@ class SGraph:
     def del_edge(self, u, v):
         self.gr.remove_edge(u, v)
 
-    def del_edges_(self, edges):
+    def del_edges(self, edges):
         self.gr.remove_edges_from(edges)
 
     def add_path(self, path):
@@ -327,7 +327,7 @@ class SGraph:
         lv = np.unique(lv, return_counts=count)
         return np.array(xs), lv
 
-    def get_all_short_pathes(self, nodes):
+    def get_all_short_pathes(self, nodes, plain=True):
         if len(nodes) < 2:
             return [], []
 
@@ -336,12 +336,19 @@ class SGraph:
         for node in nodes:
             pathes_, ln_ = self.get_short_paths(node, nodes)
             pathes += pathes_
-            ln += ln_
-        return pathes, ln
+            if plain:
+                ln += ln_
+            else:
+                if len(ln_) != 0:
+                    ln += [ln_]
+        return pathes, np.array(ln)
+
+    def get_short_line_paths(self, root, nodes=None):
+        if nodes is None:
+            nodes = self.get_ids(stable=True)
 
-    def get_short_line_paths(self, root):
         pathes, ln = [], []
-        for node in self.get_ids():
+        for node in nodes:
             if root == node:
                 continue
             path = next(nx.all_shortest_paths(self.gr, source=root, target=node, method="bellman-ford"))
