@@ -82,10 +82,12 @@ class Creator:
         path = pre + "pge/samples/networks/web-"
         if network == "BS":
             path += "BerkStan.txt"
-        if network == "S":
+        elif network == "S":
             path += "Stanford.txt"
-        if network == "G":
+        elif network == "G":
             path += "Google.txt"
+        else:
+            path = network
         return SGraph(nx.read_edgelist(path, create_using=nx.DiGraph()))
 
     @staticmethod
@@ -164,6 +166,16 @@ class Creator:
             res.del_attrs(["pos"])
         return res
 
+    @staticmethod
+    def waxman(n, beta=0.11, alpha=0.1, L=None, clean=True):
+        res = nx.waxman_graph(n, beta=beta, alpha=alpha, L=L)
+        sub = max(nx.connected_components(res), key=len)
+        res = SGraph(res).subgraph(sub)
+
+        if clean:
+            res.del_attrs(["pos"])
+        return res
+
     @staticmethod
     def chunglu(seq):
         res = nx.expected_degree_graph(seq, selfloops=False)
